@@ -3,7 +3,7 @@ from typing import List
 from pydantic import AnyHttpUrl, BaseModel
 
 
-class ConformanceClasses(BaseModel):
+class Conformance(BaseModel):
     """
     https://github.com/radiantearth/stac-api-spec/blob/master/api-spec.md#ogc-api---features-endpoints
     """
